@@ -336,7 +336,7 @@ request_frame(struct session *ses, unsigned char *name,
 	foreach (frame, loc->frames) {
 		struct document_view *doc_view;
 
-		if (strcasecmp(frame->name, name))
+		if (c_strcasecmp(frame->name, name))
 			continue;
 
 		foreach (doc_view, ses->scrn_frames) {
@@ -423,7 +423,9 @@ load_ecmascript_imports(struct session *ses, struct document_view *doc_view)
 #define load_ecmascript_imports(ses, doc_view)
 #endif
 
-inline void
+/* can't be inline according to C99 6.7.4p3 because it uses static
+ * request_frameset() and is not itself static */
+void
 load_frames(struct session *ses, struct document_view *doc_view)
 {
 	struct document *document = doc_view->document;
@@ -740,15 +742,15 @@ setup_first_session(struct session *ses, struct uri *uri)
 	if (!*get_opt_str("protocol.http.user_agent")) {
 		info_box(term, 0,
 			 N_("Warning"), ALIGN_CENTER,
-			 N_("You have empty string in protocol.http.user_agent - "
+			 N_("You have an empty string in protocol.http.user_agent - "
 			 "this was a default value in the past, substituted by "
 			 "default ELinks User-Agent string. However, currently "
 			 "this means that NO User-Agent HEADER "
 		 	 "WILL BE SENT AT ALL - if this is really what you want, "
-			 "set its value to \" \", otherwise please delete line "
-			 "with this settings from your configuration file (if you "
+			 "set its value to \" \", otherwise please delete the line "
+			 "with this setting from your configuration file (if you "
 			 "have no idea what I'm talking about, just do this), so "
-			 "that correct default setting will be used. Apologies for "
+			 "that the correct default setting will be used. Apologies for "
 			 "any inconvience caused."));
 	}
 
@@ -765,11 +767,11 @@ setup_first_session(struct session *ses, struct uri *uri)
 				 "the last time you upgraded ELinks. Now, only "
 				 "those options which you actually changed are "
 				 "saved to the configuration file, instead of "
-				 "just all the options. This simplifies our "
+				 "all the options. This simplifies our "
 				 "situation greatly when we see that some option "
-				 "has inappropriate default value or we need to "
-				 "change semantic of some option in a subtle way. "
-				 "Thus, we recommend you to change the value of "
+				 "has an inappropriate default value or we need to "
+				 "change the semantics of some option in a subtle way. "
+				 "Thus, we recommend you change the value of "
 				 "config.saving_style option to 3 in order to get "
 				 "the \"right\" behaviour. Apologies for any "
 				 "inconvience caused."));
@@ -1215,7 +1217,7 @@ ses_find_frame(struct session *ses, unsigned char *name)
 	if_assert_failed return NULL;
 
 	foreachback (frame, loc->frames)
-		if (!strcasecmp(frame->name, name))
+		if (!c_strcasecmp(frame->name, name))
 			return frame;
 
 	return NULL;
